Shorthand to the subset function.
Function to replace specific elements in a gridlayer object
# S4 method for gridlayer,ANY,missing
[(x, i)# S4 method for gridlayer,Extent,missing
[(x, i)
# S4 method for gridlayer,ANY,ANY
[(x, i) <- value
(facelayer) The object to be subsetted.
(logical, numeric nor extent) The subscript vector, or extent, specifying the faces that are used for subsetting. As in subset.
The replacement values.
The extraction methods return facelayer-class objects.
All these methods are implementing direct replacement in the @values slot of a layer, depending on criteria used for subsetting.