centers: The face centers of an icosahedral grid object
Description
Shorthand function to return the @faceCenters slot of an icosahedral grid or a grid linked to a facelayer.
Usage
centers(x, ...)# S4 method for trigrid
centers(x, output = "polar")
# S4 method for facelayer
centers(x, output = "polar")
Arguments
...
Arguments passed to the class specific methods.
output
(character) The coordinate system of the output. Either "polar" or "cartesian".
Value
The coordinates of the face centers as a numeric matrix.
Examples
Run this code# NOT RUN {
a <- trigrid()
centers(a)
# }
Run the code above in your browser using DataLab