trigrid and hexagrid objectsrotate# S4 method for trigrid
rotate(x, angles = "random", pivot = NA)
(numeric): The vector of rotation in radians (three values in each dimension). If set to "random", the rotation will be random (default).
(numeric): The pivot point of the rotation, vector of xyz coordinates. Defaults to NA indicating that the rotation will be around the center of the grid.
An object of class standardGeneric of length 1.