powered by
This function will return a value that is proportional to the irregularity of a triangonal face or subface. The ratio of the lengths of the shortest and the longest edges.
trishape(gridObj)# S4 method for trigrid trishape(gridObj)# S4 method for hexagrid trishape(gridObj)
# S4 method for trigrid trishape(gridObj)
# S4 method for hexagrid trishape(gridObj)
(trigrid, hexagrid) Object.
trigrid
hexagrid
A named numeric vector, one value for every face of the grid.
numeric
The value is exactly 1 for an equilateral triangle, and becomes 0 as one of the edges approach 0.
1
0
# NOT RUN { g <- trigrid(3) shape <- trishape(g) # }
Run the code above in your browser using DataLab